@@ -38,7 +38,7 @@ async def main():
             csv_file = csv.reader(f, delimiter=";")
 
             for index, row in enumerate(csv_file):
-                if index == 0 or row[1] == "":
+                if index == 0 or row[1] == "" or row[2] == "":
                     continue
 
                 produto_estoque = Produto(
@@ -49,12 +49,12 @@ async def main():
                 produto_bling = await bling_controller.get_produto(str(row[0]))
 
                 if produto_skyhub:
-                    print(index, produto_skyhub)
+                    print(f"{index:<6} {produto_skyhub}")
                     if produto_skyhub.price != row[1] or produto_skyhub.qty != row[2]:
                         await skyhub_controller.atualiza_produto(produto_estoque)
 
                 if produto_bling:
-                    print(index, produto_bling)
+                    print(f"{index:<6} {produto_bling}")
                     if produto_bling.price != row[1] or produto_bling.qty != row[2]:
                         await bling_controller.atualiza_produto(produto_estoque)
 
@@ -62,9 +62,10 @@ async def main():
 if __name__ == "__main__":
     try:
         asyncio.run(main())
+        # teste()
 
     except KeyboardInterrupt:
         sys.exit()
 
-    # except Exception as e:
-    #     send_message(e)
+    except Exception as e:
+        send_message(e)
