@@ -1,5 +1,5 @@
 import logging
-
+import xml
 from aiohttp import ClientSession
 
 from skyhub.loggin_config import *
@@ -18,9 +18,10 @@ class BlingController:
         self.request = request
 
     async def get_produto(self, sku: str) -> Produto:
-        url = f"{self.base_url}/{sku}/json?estoque=S"
+        apikey = self.credentials.get("apikey", "")
+        url = f"{self.base_url}/{sku}/json?apikey={apikey}&estoque=S"
         response = await self.request.request(
-            method="GET", url=url, params=self.credentials
+            method="GET", url=url
         )
         response_json = await response.json()
         retorno = response_json.get("retorno")
@@ -37,7 +38,7 @@ class BlingController:
             preco = produtoJson.get("preco")
             estoque_atual = produtoJson.get("estoqueAtual")
 
-            return Produto(codigo, preco, estoque_atual)
+            return Produto(codigo, preco or 0, estoque_atual or 0)
 
     async def atualiza_produto(self, produto: Produto) -> bool:
         xml = produto.toXML()
@@ -51,7 +52,7 @@ class BlingController:
         if response.status == 200:
             logger.info(f"O produto '{produto.sku}' foi atualizado.")
             return True
-        
+
         elif response.status == 429:
             response = await self.request.request(method="POST", url=url, data=data)
 
