@@ -25,8 +25,8 @@ class SkyhubController:
         produto = await response.json()
 
         if response.status == 200:
-            qty = produto["qty"]  # Quantidade
-            price = produto["price"]  # Preço
+            qty = produto["qty"] if produto["qty"] != None else 0
+            price = produto["price"] if produto["price"] != None else 0
             return Produto(sku, price, qty)
 
         elif response.status == 404:
@@ -38,16 +38,20 @@ class SkyhubController:
     async def atualiza_produto(self, produto: Produto) -> bool:
         produtoJSON = produto.toJson()
         url = f"{self.base_url}/{produto.sku}"
-        
-        response = await self.request.request(method="PUT", url=url, data=produtoJSON, headers=self.credentials)
+
+        response = await self.request.request(
+            method="PUT", url=url, data=produtoJSON, headers=self.credentials
+        )
         print(f"SkyHub {response.status}", end=" ")
 
         if response.status == 204:
             logger.info(f"O produto '{produto.sku}' foi atualizado.")
             return True
-        
+
         if response.status == 429:
-            response = await self.request.request(method="PUT", url=url, data=produtoJSON, headers=self.credentials)
+            response = await self.request.request(
+                method="PUT", url=url, data=produtoJSON, headers=self.credentials
+            )
 
         else:
             logger.warning(f"O produto '{produto.sku}' não pode ser atualizado.")
